from flask import Flask, request, redirect, url_for, render_template
import sqlite3

app = Flask(__name__)

# Initialize the database
def init_db():
    conn = sqlite3.connect('database.db')
    c = conn.cursor()
    c.execute('''CREATE TABLE IF NOT EXISTS proposals
                 (id INTEGER PRIMARY KEY, title TEXT, body TEXT)''')
    c.execute('''CREATE TABLE IF NOT EXISTS votes
                 (id INTEGER PRIMARY KEY, proposal_id INTEGER, vote_type TEXT,
                  FOREIGN KEY(proposal_id) REFERENCES proposals(id))''')
    conn.commit()
    conn.close()

init_db()

@app.route('/')
def index():
    conn = sqlite3.connect('database.db')
    c = conn.cursor()
    c.execute('SELECT id, title FROM proposals')
    proposals = c.fetchall()
    conn.close()
    return render_template('index.html', proposals=proposals)

@app.route('/submit', methods=['GET', 'POST'])
def submit():
    if request.method == 'POST':
        title = request.form['title']
        body = request.form['body']
        conn = sqlite3.connect('database.db')
        c = conn.cursor()
        c.execute('INSERT INTO proposals (title, body) VALUES (?, ?)', (title, body))
        conn.commit()
        conn.close()
        return redirect(url_for('index'))
    return render_template('submit.html')

@app.route('/proposal/<int:proposal_id>', methods=['GET', 'POST'])
def proposal(proposal_id):
    conn = sqlite3.connect('database.db')
    c = conn.cursor()
    if request.method == 'POST':
        vote_type = request.form['vote_type']
        c.execute('INSERT INTO votes (proposal_id, vote_type) VALUES (?, ?)', (proposal_id, vote_type))
        conn.commit()
    c.execute('SELECT title, body FROM proposals WHERE id = ?', (proposal_id,))
    proposal = c.fetchone()
    c.execute('SELECT vote_type, COUNT(*) FROM votes WHERE proposal_id = ? GROUP BY vote_type', (proposal_id,))
    votes = c.fetchall()
    vote_counts = {vote_type: count for vote_type, count in votes}
    conn.close()
    return render_template('proposal.html', proposal=proposal, vote_counts=vote_counts)

if __name__ == '__main__':
    app.run(debug=True)